keyword

# XMLRésuméLibrary: User Guide

jobtitle | Element Reference | keywords

## Name

keyword — A keyword to be used for résumé indexing and searching

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `keyword` element specifies a word or phrase that is to be used to index and/or search a résumé, usually on a computer.

Keywords are often used to specify “buzzwords” that are not (or that are) in the main text of the résumé, but may be used by employers or recruiters to find résumés.

### Parents

`keyword` may be contained in these elements: `keywords`

## Examples

    <keywords>
      <keyword>forward-thinking</keyword>
      <keyword>self-starter</keyword>
      <keyword>independent</keyword>
      <keyword>flexible</keyword>
    </keywords>

jobtitle | Element Reference | keywords